--[[
script version 1.5
this pricing script is designed for individuals to create or collect there own pricing information in whatever means they so choose and import that information into the magic album application.
to do so create the file "cardprices.txt" in the root folder of the magic album application.  inside the file each line represents a card and its associated information.  the expected line format is as follows:
(cardname{tab}cardprice{tab}setname{tab}cardlanguage{tab}cardversion{tab}foil/nonfoil)
valid complete example line:
Abuna Acolyte	0.24	Scars of Mirrodin	English	*	nonfoil
Abuna Acolyte	0.24	Scars of Mirrodin	English	0	nonfoil

valid part-complete example line:
Abuna Acolyte	0.24	Scars of Mirrodin			

invalid line examples:
Abuna Acolyte	0.24	SOM	eng	0	nonfoil
Abuna Acolyte	0.24		eng	0	nonfoil

requirements:
setname must match setnames defined in "tab" table (see below)
cardlanguage must match a language  defined in the suplang table (see below)
price values must not contain commas
you must define a card name
you must define a card price
you must define a card set name
all other values if not present will use default values listed below

defaults:
cardlanguage will default to english (eng)
cardversion will default to * (all versions)
cardfoiling will default to nonfoil

variable descriptions:
nfnum 	non foil numbers	the number to start counting from when a new non foil card is imported (recommended to leave at 0)
fnum	foil numbers		the number to start counting from when a new foil card is imported (recommended to leave at 0)
dbg		debug				"on" turns debuging on, "off" turns debuging off
cpf		card price file		file (including path if not local) to the file containing the card pricing information

tab table description:
id		id					setid used in the magic album application
setname	setname				name of set associated with id
block	blockname			name of block the setname is associated with

suplang table description:
full	language full name		MA supported language full name
abbr	language abbr name		MA supported language abbreviation letters
--]]

tab ={
	{id = 784, setname = "Dark Ascension", block = "Innistrad"},
	{id = 783, setname = "Premium Deck Series: Graveborn", block = "Decks"},
	{id = 782, setname = "Innistrad", block = "Innistrad"},
	{id = 781, setname = "Duel Decks: Ajani vs. Nicol Bolas", block = "Duel Decks"},
	{id = 780, setname = "From the Vault: Legends", block = "From the Vault"},
	{id = 779, setname = "Magic 2012", block = "Core Sets"},
	{id = 778, setname = "Magic: The Gathering Commander", block = "Casual Supplements"},
	{id = 778, setname = "Magic: The Gathering Commander Oversized", block = "Casual Supplements"},
	{id = 777, setname = "Duel Decks: Knights vs. Dragons", block = "Duel Decks"},
	{id = 776, setname = "New Phyrexia", block = "Scars of Mirrodin"},
	{id = 775, setname = "Mirrodin Besieged", block = "Scars of Mirrodin"},
	{id = 774, setname = "Premium Deck Series: Fire & Lightning", block = "Decks"},
	{id = 773, setname = "Scars of Mirrodin", block = "Scars of Mirriodin"},
	{id = 772, setname = "Duel Decks: Elspeth vs. Tezzeret", block = "Duel Decks"},
	{id = 771, setname = "From the Vault: Relics", block = "From the Vault"},
	{id = 770, setname = "Magic 2011", block = "Core Sets"},
	{id = 769, setname = "Archenemy", block = "Casual Supplements"},
	{id = 768, setname = "Duels of the Planeswalkers", block = "Decks"},
	{id = 767, setname = "Rise of the Eldrazi", block = "Zendikar"},
	{id = 766, setname = "Duel Decks: Phyrexia vs. The Coalition", block = "Duel Decks"},
	{id = 765, setname = "WorldWake", block = "Zendikar"},
	{id = 764, setname = "Premium Deck Series: Slivers", block = "Decks"},
	{id = 763, setname = "Duel Decks: Garruk vs. Liliana", block = "Duel Decks"},
	{id = 762, setname = "Zendikar", block = "Zendikar"},
	{id = 761, setname = "Planechase", block = "Casual Supplements"},
	{id = 760, setname = "From the Vault: Exiled", block = "From the Vault"},
	{id = 759, setname = "Magic 2010", block = "Core Sets"},
	{id = 758, setname = "Alara Reborn", block = "Shards of Alara"},
	{id = 757, setname = "Duel Decks: Divine vs. Demonic", block = "Duel Decks"},
	{id = 756, setname = "Conflux", block = "Shards of Alara"},
	{id = 755, setname = "Duel Decks: Jace vs. Chandra", block = "Duel Decks"},
	{id = 754, setname = "Shards of Alara", block = "Shards of Alara"},
	{id = 753, setname = "From the Vault: Dragons", block = "From the Vault"},
	{id = 752, setname = "Eventide", block = "Lorwyn-Shadowmoor"},
	{id = 751, setname = "Shadowmoor", block = "Lorwyn-Shadowmoor"},
	{id = 750, setname = "Morningtide", block = "Lorwyn-Shadowmoor"},
	{id = 740, setname = "Duel Decks: Elves vs. Goblins", block = "Duel Decks"},
	{id = 730, setname = "Lorwyn", block = "Lorwyn-Shadownmoor"},
	{id = 720, setname = "Tenth Edition", block = "Core Sets"},
	{id = 710, setname = "Future Sight", block = "Time Spiral"},
	{id = 700, setname = "Planar Chaos", block = "Time Spiral"},
	{id = 690, setname = "Time Spiral Timeshifted", block = "Time Spiral"},
	{id = 680, setname = "Time Spiral", block = "Time Spiral"},
	{id = 675, setname = "Coldsnap Them Decks", block = "Ice Age"},
	{id = 670, setname = "Coldsnap", block = "Ice Age"},
	{id = 660, setname = "Dissension", block = "Ravnica"},
	{id = 650, setname = "Guildpact", block = "Ravnica"},
	{id = 640, setname = "Ravnica: City of Guilds", block = "Ravnica"},
	{id = 635, setname = "Magic Encyclopedia", block = ""},
	{id = 630, setname = "9th Edition", block = "Core Sets"},
	{id = 620, setname = "Saviors of Kamigawa", block = "Kamigawa"},
	{id = 610, setname = "Betrayers of Kamigawa", block = "Kamigawa"},
	{id = 600, setname = "Unhinged", block = "Un Sets"},
	{id = 590, setname = "Champions of Kamigawa", block = "Kamigawa"},
	{id = 580, setname = "Fifth Dawn", block = "Mirrodin"},
	{id = 570, setname = "Darksteel", block = "Mirrodin"},
	{id = 560, setname = "Mirrodin", block = "Mirrodin"},
	{id = 550, setname = "8th Edition", block = "Core Sets"},
	{id = 540, setname = "Scourge", block = "Onslaught"},
	{id = 530, setname = "Legions", block = "Onslaught"},
	{id = 520, setname = "Onslaught", block = "Onslaught"},
	{id = 510, setname = "Judgment", block = "Odyssey"},
	{id = 500, setname = "Torment", block = "Odyssey"},
	{id = 490, setname = "Deckmasters", block = "Box Sets"},
	{id = 480, setname = "Odyssey", block = "Odyssey"},
	{id = 470, setname = "Apocalypse", block = "Invasion"},
	{id = 460, setname = "7th Edition", block = "Core Sets"},
	{id = 450, setname = "Planeshift", block = "Invasion"},
	{id = 440, setname = "Beatdown", block = "Box Sets"},
	{id = 430, setname = "Invasion", block = "Invasion"},
	{id = 420, setname = "Prophecy", block = "Masques"},
	{id = 415, setname = "Starter 2000", block = "Portal / Starter"},
	{id = 410, setname = "Nemesis", block = "Masques"},
	{id = 405, setname = "Battle Royale", block = "Box Sets"},
	{id = 400, setname = "Mercadian Masques", block = "Masques"},
	{id = 390, setname = "Starter 1999", block = "Portal / Starter"},
	{id = 380, setname = "Portal Three Kingdoms", block = "Portal / Starter"},
	{id = 370, setname = "Urza's Destiny", block = "Urza"},
	{id = 360, setname = "6th Edition", block = "Core Sets"},
	{id = 350, setname = "Urza's Legacy", block = "Urza"},
	{id = 340, setname = "Anthologies", block = "Reprint"},
	{id = 330, setname = "Urza's Saga", block = "Urza"},
	{id = 320, setname = "Unglued", block = "Un Sets"},
	{id = 310, setname = "Portal Second Age", block = "Portal / Starter"},
	{id = 300, setname = "Exodus", block = "Tempest"},
	{id = 290, setname = "Stronghold", block = "Tempest"},
	{id = 280, setname = "Tempest", block = "Tempest"},
	{id = 270, setname = "Weatherlight", block = "Mirage"},
	{id = 260, setname = "Portal", block = "Portal / Starter"},
	{id = 250, setname = "5th Edition", block = "Core Sets"},
	{id = 240, setname = "Visions", block = "Mirage"},
	{id = 230, setname = "Mirage", block = "Mirage"},
	{id = 225, setname = "Introductory Two-Player Set", block = ""},
	{id = 220, setname = "Alliances", block = "Ice Age"},
	{id = 210, setname = "Homelands", block = "Ice Age"},
	{id = 200, setname = "Chronicles", block = "Reprint"},
	{id = 190, setname = "Ice Age", block = "Ice Age"},
	{id = 180, setname = "4th Edition", block = "Core Sets"},
	{id = 170, setname = "Fallen Empires", block = "Stand Alone"},
	{id = 160, setname = "The Dark", block = "Stand Alone"},
	{id = 150, setname = "Legends", block = "Stand Alone"},
	{id = 140, setname = "Revised", block = "Core Sets"},
	{id = 130, setname = "Antiquities", block = "Stand Alone"},
	{id = 120, setname = "Arabian Nights", block = "Stand Alone"},
	{id = 110, setname = "Unlimited", block = "Core Sets"},
	{id = 100, setname = "Beta", block = "Core Sets"},
	{id = 90, setname = "Alpha", block = "Core Sets"},
	{id = 70, setname = "Vanguard", block = "Casual Supplements"},
	{id = 50, setname = "Full Box Promotion", block = "Promo"},
	{id = 45, setname = "Magic Premiere Shop", block = "Promo"},
	{id = 43, setname = "Two-Headed Giant Promos", block = "Promo"},
	{id = 42, setname = "Summer of Magic Promos", block = "Promo"},
	{id = 41, setname = "Happy Holidays Promos", block = "Promo"},
	{id = 40, setname = "Arena League Promos", block = "Promo"},
	{id = 33, setname = "World Championship Cards", block = "Decks"},
	{id = 32, setname = "Pro Tour Promos", block = "Promo"},
	{id = 31, setname = "Grand Prix Promos", block = "Promo"},
	{id = 30, setname = "Friday Night Magic Promos", block = "Promo"},
	{id = 27, setname = "Alternate Art Lands", block = "Promo"},
	{id = 26, setname = "Magic Game Day", block = "Promo"},
	{id = 25, setname = "Judge Gift Cards", block = "Promo"},
	{id = 24, setname = "Champs Promos", block = "Promo"},
	{id = 23, setname = "Gateway & WPN Promos", block = "Promo"},
	{id = 22, setname = "Prerelease Promos", block = "Promo"},
	{id = 21, setname = "Release & Launch Parties Promos", block = "Promo"},
	{id = 20, setname = "Magic Player Rewards", block = "Promo"},
	{id = 15, setname = "Convention Promos", block = "Promo"},
	{id = 10, setname = "Junior Series Promos", block = "Promo"},
	{id = 9, setname = "Video Game Promos", block = "Promo"},
	{id = 8, setname = "Stores Promos", block = "Promo"},
	{id = 7, setname = "Magazine Inserts", block = "Promo"},
	{id = 6, setname = "Comic Inserts", block = "Promo"},
	{id = 5, setname = "Book Inserts", block = "Promo"},
	{id = 4, setname = "Richard Garfield Events", block = "Promo"},
	{id = 2, setname = "DCI Legend Membership", block = "Promo"},
	{id = 1, setname = "Other Promos", block = "Promo"},
	}
	
suplang = {
	  {full = "English", abbr="ENG"},
	  {full = "Russian", abbr="RUS"},
	  {full = "German", abbr="GER"},
	  {full = "French", abbr="FRA"},
	  {full = "Italian", abbr="ITA"},
	  {full = "Portuguese", abbr="POR"},
	  {full = "Spanish", abbr="SPA"},
	  {full = "Japanese", abbr="JPN"},
	  {full = "Simplified Chinese", abbr="ZHC"},
	  {full = "Traditional Chinese", abbr="ZHT"},
	  {full = "Korean", abbr="KOR"},
	  {full = "Hebrew", abbr="HEB"},
	  {full = "Arabic", abbr="ARA"},
	  {full = "Latin", abbr="LAT"},
	  {full = "Sanskrit", abbr="SAN"},
	  {full = "Ancient Greek", abbr="GRC"},
	  {full = "english", abbr="ENG"},
	  {full = "russian", abbr="RUS"},
	  {full = "german", abbr="GER"},
	  {full = "french", abbr="FRA"},
	  {full = "italian", abbr="ITA"},
	  {full = "portuguese", abbr="POR"},
	  {full = "spanish", abbr="SPA"},
	  {full = "japanese", abbr="JPN"},
	  {full = "simplified chinese", abbr="ZHC"},
	  {full = "traditional chinese", abbr="ZHT"},
	  {full = "korean", abbr="KOR"},
	  {full = "hebrew", abbr="HEB"},
	  {full = "arabic", abbr="ARA"},
	  {full = "latin", abbr="LAT"},
	  {full = "sanskrit", abbr="SAN"},
	  {full = "ancient greek", abbr="GRC"},
}
	
function explode(d,p)
	local t, ll
	t={}
	ll=0
	if(#p == 1) then return p end
	while true do
		l=string.find(p,d,ll+1,true)
		if l~=nil then
			table.insert(t, string.sub(p,ll,l-1))
			ll=l+1
		else
			table.insert(t, string.sub(p,ll))
			break
		end
	end
	return t
end
	
function trimspaces (s)
      return (string.gsub(s, "^%s*(.-)%s*$", "%1"))
end

--declare user defined variable(s)
nfnum = 0					--recommended value: 0
fnum = 0					--recommended value: 0
cpf = "MagicTraders.txt"	--recommended value: name according to website the prices are pulled from
dbg = "off"					--recommended value: off {available values: on,off}

function Start()

	openfile = io.open(cpf, "r")
	while true do
		--expected line format (cardname{tab}cardprice{tab}setname{tab}cardlanguage{tab}cardversion{tab}foil/nonfoil)
		line = openfile:read("*line")
		if not line then break end
		--write debug information (if dbg is on)
		if dbg ~= "off" then ma.Log("currentline: [" .. line .. "]") end
		linesplit = explode("\t",line)
		lsc = 1
		--clear any previous card details
		cardname = nil
		cardcost = nil
		cardset = nil
		cardlanguage = nil
		cardversion = nil
		cardfoiling = nil
		cardsetid = nil
		cardblockname = nil
		cardabbr = nil
		els = 6
		cardlinevalid = "no"
		debugline = nil
		--define new card details
		for i in ipairs(linesplit) do
			if lsc == 1 then cardname = trimspaces(linesplit[i]) end
			if lsc == 2 then cardcost = trimspaces(linesplit[i]) end
			if lsc == 3 then cardset = trimspaces(linesplit[i]) end
			if lsc == 4 then cardlanguage = linesplit[i] end
			if lsc == 5 then cardversion = linesplit[i] end
			if lsc == 6 then cardfoiling = linesplit[i] end
			if lsc > els then break end 
			lsc = lsc + 1
		end
		--identify card set id  and block from setname
		for _,rec in ipairs(tab) do
			if cardset == rec.setname then
				cardsetid = rec.id
				cardblockname = rec.block
			end 
		end
		--identify card language abbr
		for _,rec in ipairs(suplang) do
			if cardlanguage == rec.full then
				cardabbr = rec.abbr
			end
		end
		
		--verify required fields are set before attempting to set card price
		if lsc == 7 then
			if cardsetid ~= nil then
				if cardname ~= nil then
					if cardcost ~= nil then
						cardlinevalid = "yes"
						--define default values if values are not present
						if cardversion == "0" then cardversion = "" end
						if cardversion == "1" then cardversion = 1 end
						if cardversion == "2" then cardversion = 2 end
						if cardversion == "3" then cardversion = 3 end
						if cardversion == "4" then cardversion = 4 end
						if cardversion == nil then cardversion = "*" end
						if cardlanguage == nil then cardlanguage = "ENG" end
						if cardfoiling == nil then cardfoiling = "nonfoil" end
						
						--write debug information (if dbg is on)
						if dbg ~= "off" then
							if cardname ~= nil then
								if debugline == nil then debugline = "[" .. cardname .. "]" else debugline = debugline .. ",[" .. cardname .. "]" end
							else
								if debugline == nil then debugline = "[]" else debugline = debugline .. ",[]" end
							end
							if cardcost ~= nil then
								if debugline == nil then debugline = "[" .. cardcost .. "]" else debugline = debugline .. ",[" .. cardcost .. "]" end
							else
								if debugline == nil then debugline = "[]" else debugline = debugline .. ",[]" end
							end
							if cardset ~= nil then
								if debugline == nil then debugline = "[" .. cardset .. "]" else debugline = debugline .. ",[" .. cardset .. "]" end
							else
								if debugline == nil then debugline = "[]" else debugline = debugline .. ",[]" end
							end
							if cardlanguage ~= nil then
								if debugline == nil then debugline = "[" .. cardlanguage .. "]" else debugline = debugline .. ",[" .. cardlanguage .. "]" end
							else
								if debugline == nil then debugline = "[]" else debugline = debugline .. ",[]" end
							end
							if cardversion ~= nil then
								if debugline == nil then debugline = "[" .. cardversion .. "]" else debugline = debugline .. ",[" .. cardversion .. "]" end
							else
								if debugline == nil then debugline = "[]" else debugline = debugline .. ",[]" end
							end
							if cardfoiling ~= nil then
								if debugline == nil then debugline = "[" .. cardfoiling .. "]" else debugline = debugline .. ",[" .. cardfoiling .. "]" end
							else
								if debugline == nil then debugline = "[]" else debugline = debugline .. ",[]" end
							end
							
						end
					
					
						if string.lower(cardfoiling) == "nonfoil" then
							--set nonfoil card price
							ma.SetPrice(cardsetid,cardabbr,cardname,cardversion,cardcost,0)
							nfnum = nfnum + 1
						end
						if string.lower(cardfoiling) == "foil" then
							--set foil card price
							ma.SetPrice(cardsetid,cardabbr,cardname,cardversion,0,cardcost)
							fnum = fnum + 1
						end
					end
				end
			end
		else
			--write debug information (if dbg is on)
			if dbg ~= "off" then
				if cardname ~= nil then
					if debugline == nil then debugline = "[" .. cardname .. "]" else debugline = debugline .. ",[" .. cardname .. "]" end
				else
					if debugline == nil then debugline = "[]" else debugline = debugline .. ",[]" end
				end
				if cardcost ~= nil then
					if debugline == nil then debugline = "[" .. cardcost .. "]" else debugline = debugline .. ",[" .. cardcost .. "]" end
				else
					if debugline == nil then debugline = "[]" else debugline = debugline .. ",[]" end
				end
				if cardset ~= nil then
					if debugline == nil then debugline = "[" .. cardset .. "]" else debugline = debugline .. ",[" .. cardset .. "]" end
				else
					if debugline == nil then debugline = "[]" else debugline = debugline .. ",[]" end
				end
				if cardlanguage ~= nil then
					if debugline == nil then debugline = "[" .. cardlanguage .. "]" else debugline = debugline .. ",[" .. cardlanguage .. "]" end
				else
					if debugline == nil then debugline = "[]" else debugline = debugline .. ",[]" end
				end
				if cardversion ~= nil then
					if debugline == nil then debugline = "[" .. cardversion .. "]" else debugline = debugline .. ",[" .. cardversion .. "]" end
				else
					if debugline == nil then debugline = "[]" else debugline = debugline .. ",[]" end
				end
				if cardfoiling ~= nil then
					if debugline == nil then debugline = "[" .. cardfoiling .. "]" else debugline = debugline .. ",[" .. cardfoiling .. "]" end
				else
					if debugline == nil then debugline = "[]" else debugline = debugline .. ",[]" end
				end
			end
		end
		--write invalid formated lines to MA log file
		if cardlinevalid == "no" then
			ma.Log("[WARNING]\tInvalidPriceLine: (" .. line .. ")")
			ma.Log(debugline)
		end
	end
	ma.Log(nfnum .. " total non-foil card price(s) set")
	ma.Log(fnum .. " total foil card price(s) set")
end
